# scikit-weak (scikit-weakly-supervised)

![scikit-weak logo](images/scikit_weak_logo.png)

 A package featuring utilities and algorithms for weakly supervised ML.
 Should be (more-or-less) compatible with scikit-learn!
 It collects original algorithms and methods developed by the contributors,
 as well as some algorithms available in the literature.

 Current contributors:
 - Andrea Campagner, MUDI Lab, University of Milano-Bicocca
 - Julian Lienen, Paderborn University

 ## How to install
 You can install the library using the command:

 ```
 pip install scikit-weak
 ```
 
 ### Dependencies:
 numpy, scipy, scikit-learn, tensorflow, keras, pytest

 ## Documentation
 The documentation is generated using Sphinx (https://www.sphinx-doc.org/). 
 If you download the source code from this repository you can generate the documentation in html format by typing: 
 ```
 pip install sphinx-rtd-theme
 sphinx-build -b html docs/source docs/build/html
 ```
 in the main folder of the project.


